==> cuteradio_0.2.0.tar.gz: cuteradio-0.2.0/src/symbian/launcher.cpp <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "launcher.h"
#include "../base/settings.h"
#include <QTemporaryFile>
#include <QDir>
#include <QTimer>
#include <QDesktopServices>

Launcher* Launcher::self = 0;

Launcher::Launcher(QObject *parent) :
    QObject(parent)
{
    if (!self) {
        self = this;
    }
}

Launcher::~Launcher() {}

Launcher* Launcher::instance() {
    return !self ? new Launcher : self;
}

void Launcher::launch(const QUrl &url) {
    QTemporaryFile *temp = new QTemporaryFile;
    temp->setFileName(QDir::tempPath() + "/cuteradio.ram");

    if ((temp->open()) && (temp->write(QByteArray::fromPercentEncoding(url.toString().toUtf8())) > 0)) {
        QDesktopServices::openUrl(QUrl::fromLocalFile(temp->fileName()));
    }

    temp->close();
    QTimer::singleShot(5000, temp, SLOT(deleteLater()));
}

void Launcher::launch(QList<QUrl> urls) {
    QTemporaryFile *temp = new QTemporaryFile;
    temp->setFileName(QDir::tempPath() + "/cuteradio.m3u");

    if (temp->open()) {
        while (!urls.isEmpty()) {
            temp->write(urls.takeFirst().toString().toUtf8() + '\n');
        }

        QDesktopServices::openUrl(QUrl::fromLocalFile(temp->fileName()));
    }

    temp->close();
    QTimer::singleShot(5000, temp, SLOT(deleteLater()));
}

==> cuteradio_0.2.1.tar.gz: cuteradio-0.2.1/src/symbian/launcher.cpp <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <QTemporaryFile>
#include <QDir>
#include <QTimer>
#include <QDesktopServices>
#include "launcher.h"
#include "../base/settings.h"

Launcher* Launcher::self = 0;

Launcher::Launcher(QObject *parent) :
    QObject(parent)
{
    if (!self) {
        self = this;
    }
}

Launcher::~Launcher() {}

Launcher* Launcher::instance() {
    return !self ? new Launcher : self;
}

void Launcher::launch(const QUrl &url) {
    QTemporaryFile *temp = new QTemporaryFile;
    temp->setFileName(QDir::tempPath() + "/cuteradio.ram");

    if ((temp->open()) && (temp->write(QByteArray::fromPercentEncoding(url.toString().toUtf8())) > 0)) {
        QDesktopServices::openUrl(QUrl::fromLocalFile(temp->fileName()));
    }

    temp->close();
    QTimer::singleShot(5000, temp, SLOT(deleteLater()));
}

void Launcher::launch(QList<QUrl> urls) {
    QTemporaryFile *temp = new QTemporaryFile;
    temp->setFileName(QDir::tempPath() + "/cuteradio.m3u");

    if (temp->open()) {
        while (!urls.isEmpty()) {
            temp->write(QByteArray::fromPercentEncoding(urls.takeFirst().toString().toUtf8()) + '\n');
        }

        QDesktopServices::openUrl(QUrl::fromLocalFile(temp->fileName()));
    }

    temp->close();
    QTimer::singleShot(5000, temp, SLOT(deleteLater()));
}
